@@ -28,7 +28,7 @@
 #' \describe{
 #'   \item{STATION_NUMBER}{Unique 7 digit Water Survey of Canada station number}
 #'   \item{Date}{Observation date. Formatted as a Date class.}
-#'   \item{Parameter}{Parameter being measured. Only possible value is FLOW}
+#'   \item{Parameter}{Parameter being measured. Only possible value is Flow}
 #'   \item{Value}{Discharge value. The units are m^3/s.}
 #'   \item{Symbol}{Measurement/river conditions}
 #' }
@@ -116,7 +116,7 @@ hy_daily_flows <- function(station_number = NULL,
   dly_flows <- dplyr::collect(dly_flows)
   
   if(is.data.frame(dly_flows) && nrow(dly_flows)==0)
-    {stop("This station is not present in HYDAT")}
+    {stop("No flow data for this station in HYDAT")}
   
   dly_flows <- tidyr::gather(dly_flows, variable, temp, -(STATION_NUMBER:NO_DAYS))
   dly_flows <- dplyr::mutate(dly_flows, DAY = as.numeric(gsub("FLOW|FLOW_SYMBOL", "", variable)))
@@ -136,7 +136,7 @@ hy_daily_flows <- function(station_number = NULL,
   }
   
   dly_flows <- dplyr::left_join(dly_flows, tidyhydat::hy_data_symbols, by = c("FLOW_SYMBOL" = "SYMBOL_ID"))
-  dly_flows <- dplyr::mutate(dly_flows, Parameter = "FLOW")
+  dly_flows <- dplyr::mutate(dly_flows, Parameter = "Flow")
   
   ## Control for symbol ouput
   if(symbol_output == "code"){
@@ -158,19 +158,8 @@ hy_daily_flows <- function(station_number = NULL,
   
   
   ## What stations were missed?
-  differ <- setdiff(unique(stns), unique(dly_flows$STATION_NUMBER))
-  if (length(differ) != 0) {
-    if (length(differ) <= 10) {
-      message("The following station(s) were not retrieved: ", paste0(differ, sep = " "))
-      message("Check station number typos or if it is a valid station in the network")
-    }
-    else {
-      message("More than 10 stations from the initial query were not returned. Ensure realtime and active status are correctly specified.")
-    }
-  } else {
-    message("All station successfully retrieved")
-  }
-
+  differ_msg(unique(stns), unique(dly_flows$STATION_NUMBER))
+  
 
   dly_flows
 }
