@@ -24,7 +24,7 @@
 #' \describe{
 #'   \item{STATION_NUMBER}{Unique 7 digit Water Survey of Canada station number}
 #'   \item{Date}{Observation date. Formatted as a Date class.}
-#'   \item{Parameter}{Parameter being measured. Only possible value is LEVEL}
+#'   \item{Parameter}{Parameter being measured. Only possible value is Level}
 #'   \item{Value}{Level value. The units are metres.}
 #'   \item{Symbol}{Measurement/river conditions}
 #' }
@@ -108,7 +108,7 @@ hy_daily_levels <- function(station_number = NULL,
   dly_levels <- dplyr::collect(dly_levels)
   
   if(is.data.frame(dly_levels) && nrow(dly_levels)==0)
-  {stop("This station is not present in HYDAT.")}
+  {stop("No level data for this station in HYDAT")}
   
   dly_levels <- tidyr::gather(dly_levels, variable, temp, -(STATION_NUMBER:NO_DAYS))
   dly_levels <- dplyr::mutate(dly_levels, DAY = as.numeric(gsub("LEVEL|LEVEL_SYMBOL", "", variable)))
@@ -127,7 +127,7 @@ hy_daily_levels <- function(station_number = NULL,
       Date <= end_date)
   }
   dly_levels <- dplyr::left_join(dly_levels, tidyhydat::hy_data_symbols, by = c("LEVEL_SYMBOL" = "SYMBOL_ID"))
-  dly_levels <- dplyr::mutate(dly_levels, Parameter = "LEVEL")
+  dly_levels <- dplyr::mutate(dly_levels, Parameter = "Level")
   
   ## Control for symbol ouput
   if(symbol_output == "code"){
@@ -148,18 +148,8 @@ hy_daily_levels <- function(station_number = NULL,
   
   
   ## What stations were missed?
-  differ <- setdiff(unique(stns), unique(dly_levels$STATION_NUMBER))
-  if (length(differ) != 0) {
-    if (length(differ) <= 10) {
-      message("The following station(s) were not retrieved: ", paste0(differ, sep = " "))
-      message("Check station number typos or if it is a valid station in the network")
-    }
-    else {
-      message("More than 10 stations from the initial query were not returned. Ensure realtime and active status are correctly specified.")
-    }
-  } else {
-    message("All station successfully retrieved")
-  }
+  differ_msg(unique(stns), unique(dly_levels$STATION_NUMBER))
+
 
   dly_levels
 }
